@@ -276,15 +276,12 @@ class SpacerakeSDK:
         
 
     async def asset_download_bytes(self, asset_id: str) -> bytes:
-        resp = await self.__request_get(
-            f'/api/v0/assets/asset/{asset_id}/download'
-        )
+        link = await self.asset_get_download_link(asset_id)
 
-        if resp.status_code == 404:
-            raise SpacerakeAPIException(APIResponse[Any].parse_obj(resp.json()).error)
+        with httpx.AsyncClient as client:
+            resp = client.get(link, follow_redirects=True)
 
-        # TODO: stream
-        return resp.content
+            return resp.content
 
 
     async def asset_download_file(self, asset_id: str, filename: str):
